@@ -154,25 +154,31 @@ class PackOS:
             self.copy(source_path, dest_path)
         else:
             iterpaths, _nexts = [str(bp)], []
-            for iterpath in iterpaths:
-                rel = os.path.relpath(iterpath, source_path)
-                self.sureDir(self.join(dest_path, rel))
-                for root, dirs, files in os.walk(str(iterpath)):
-                    for dir in dirs:
-                        source_dir = self.join(iterpath, dir)
-                        rel = os.path.relpath(source_dir, source_path)
-                        dest_dir = self.join(dest_path, rel)
-                        self.sureDir(dest_dir)
-                        _nexts += [source_dir]
-                    for file in files:
-                        dot_index = file.rfind('.')
-                        if dot_index != -1:
-                            if file[dot_index:] in specifics:
-                                sfile_path = os.path.join(root, file)
-                                rel = os.path.relpath(sfile_path, source_path)
-                                dfile_path = os.path.join(dest_path, rel)
-                                shutil.copyfile(sfile_path, dfile_path)
-            iterpaths, _nexts = _nexts, []
+            while iterpaths:
+                for iterpath in iterpaths:
+                    rel = os.path.relpath(iterpath, source_path)
+                    self.sureDir(self.join(dest_path, rel))
+                    root = iterpath
+                    for name in os.listdir(str(iterpath)):
+                        fpath = os.path.join(root, name)
+                        if os.path.isdir(fpath):
+                            dir = name
+                            source_dir = self.join(iterpath, dir)
+                            rel = os.path.relpath(source_dir, source_path)
+                            dest_dir = self.join(dest_path, rel)
+                            # print(source_dir, dir, rel, dest_dir)
+                            self.sureDir(dest_dir)
+                            _nexts += [source_dir]
+                        else:
+                            file = name
+                            dot_index = file.rfind('.')
+                            if dot_index != -1:
+                                if file[dot_index:] in specifics:
+                                    sfile_path = os.path.join(root, file)
+                                    rel = os.path.relpath(sfile_path, source_path)
+                                    dfile_path = os.path.join(dest_path, rel)
+                                    shutil.copyfile(sfile_path, dfile_path)
+                iterpaths, _nexts = _nexts, []
 
 
     def remove(self, path:str):
